@@ -463,6 +463,10 @@ add_login_options(AccountPrefsDialog *dialog, GtkWidget *parent)
 
 	/* Screen name */
 	dialog->screenname_entry = gtk_entry_new();
+#ifdef USE_HILDON
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(dialog->screenname_entry),
+		hildon_gtk_entry_get_input_mode(GTK_ENTRY(dialog->screenname_entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 #if GTK_CHECK_VERSION(2,10,0)
 	g_object_set(G_OBJECT(dialog->screenname_entry), "truncate-multiline", TRUE, NULL);
 #endif
@@ -549,6 +553,10 @@ add_login_options(AccountPrefsDialog *dialog, GtkWidget *parent)
 	gtk_entry_set_visibility(GTK_ENTRY(dialog->password_entry), FALSE);
 	if (gtk_entry_get_invisible_char(GTK_ENTRY(dialog->password_entry)) == '*')
 		gtk_entry_set_invisible_char(GTK_ENTRY(dialog->password_entry), PIDGIN_INVISIBLE_CHAR);
+#ifdef USE_HILDON
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(dialog->password_entry),
+		hildon_gtk_entry_get_input_mode(GTK_ENTRY(dialog->password_entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 	dialog->password_box = add_pref_box(dialog, vbox, _("_Password:"),
 										  dialog->password_entry);
 
@@ -856,6 +864,10 @@ add_protocol_options(AccountPrefsDialog *dialog, GtkWidget *parent)
 					gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
 					if (gtk_entry_get_invisible_char(GTK_ENTRY(entry)) == '*')
 						gtk_entry_set_invisible_char(GTK_ENTRY(entry), PIDGIN_INVISIBLE_CHAR);
+#ifdef USE_HILDON
+					hildon_gtk_entry_set_input_mode(GTK_ENTRY(entry),
+						hildon_gtk_entry_get_input_mode(GTK_ENTRY(entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 				}
 
 				/* Google Talk default domain hackery! */
@@ -1075,6 +1087,10 @@ add_proxy_options(AccountPrefsDialog *dialog, GtkWidget *parent)
 
 	/* Host */
 	dialog->proxy_host_entry = gtk_entry_new();
+#ifdef USE_HILDON
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(dialog->proxy_host_entry),
+		hildon_gtk_entry_get_input_mode(GTK_ENTRY(dialog->proxy_host_entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 	add_pref_box(dialog, vbox2, _("_Host:"), dialog->proxy_host_entry);
 
 	/* Port */
@@ -1086,6 +1102,10 @@ add_proxy_options(AccountPrefsDialog *dialog, GtkWidget *parent)
 
 	/* User */
 	dialog->proxy_user_entry = gtk_entry_new();
+#ifdef USE_HILDON
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(dialog->proxy_user_entry),
+		hildon_gtk_entry_get_input_mode(GTK_ENTRY(dialog->proxy_user_entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 
 	add_pref_box(dialog, vbox2, _("_Username:"), dialog->proxy_user_entry);
 
@@ -1094,6 +1114,10 @@ add_proxy_options(AccountPrefsDialog *dialog, GtkWidget *parent)
 	gtk_entry_set_visibility(GTK_ENTRY(dialog->proxy_pass_entry), FALSE);
 	if (gtk_entry_get_invisible_char(GTK_ENTRY(dialog->proxy_pass_entry)) == '*')
 		gtk_entry_set_invisible_char(GTK_ENTRY(dialog->proxy_pass_entry), PIDGIN_INVISIBLE_CHAR);
+#ifdef USE_HILDON
+	hildon_gtk_entry_set_input_mode(GTK_ENTRY(dialog->proxy_pass_entry),
+		hildon_gtk_entry_get_input_mode(GTK_ENTRY(dialog->proxy_pass_entry)) & ~(HILDON_GTK_INPUT_MODE_AUTOCAP));
+#endif /* USE_HILDON */
 	add_pref_box(dialog, vbox2, _("Pa_ssword:"), dialog->proxy_pass_entry);
 
 	if (dialog->account != NULL &&
@@ -1931,9 +1955,9 @@ ask_delete_account_sel(GtkTreeModel *model, GtkTreePath *path,
 							  purple_account_get_username(account));
 
 		purple_request_close_with_handle(account);
-		purple_request_action_with_hint(account, NULL, buf, NULL, 0,
+		purple_request_action(account, NULL, buf, NULL, 0,
 							account, NULL, NULL,
-							PURPLE_REQUEST_UI_HINT_ACCOUNTMGR, account, 2,
+							account, 2,
 							_("Delete"), delete_account_cb,
 							_("Cancel"), NULL);
 		g_free(buf);
